stafftools.Staff
================

.. inheritance-diagram:: abjad.tools.stafftools.Staff.Staff.Staff
   :private-bases:

.. autoclass:: abjad.tools.stafftools.Staff.Staff.Staff

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.engraver_consists

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.engraver_removals

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.is_semantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.lilypond_format

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.preprolated_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.context_name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.is_nonsemantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

Methods
-------

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.extend

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__add__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__delitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__repr__

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__setitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`
